import React, { useState } from 'react'
import { Layout, Menu, Breadcrumb, Dropdown } from 'antd'
import { RouteComponentProps, Switch, Route, Redirect, Link, matchPath } from 'react-router-dom'
import { DownOutlined } from '@ant-design/icons'
import './index.scss'
const { Header, Content, Footer, Sider } = Layout
const generateBreadcrumbNameMap = (routes: any[]) => {
  const map = {}
  routes
    .filter((element) => {
      return !element.redirect
    })
    .forEach((element) => {
      map[element.path] = element.breadcrumbName
    })
  return map
}
/**
 * @description 管理后端布局
 * @param param0
 * @returns
 */
const adminLayout: React.FC<RouteComponentProps & { routes: any[] }> = ({
  routes,
  location,
  history,
}) => {
  const [userInfo] = useState(() => {
    const localUserInfo = sessionStorage.getItem('userInfo')
    return localUserInfo && JSON.parse(localUserInfo)
  })
  const [defaultSelectedKeys] = useState(() => {
    return location.pathname
  })
  if (!userInfo) {
    return <Redirect from={location.pathname} to='/login'></Redirect>
  }
  // generate breadcrumbNameMap
  const breadcrumbNameMap = generateBreadcrumbNameMap(routes)
  /**
   * @description 生成面包屑
   * @returns
   */
  const generateBreadcrumb = () => {
    const pathSnippets = location.pathname.split('/').filter((i) => i)
    const routePath = Object.keys(breadcrumbNameMap)
    const extraBreadcrumbItems = pathSnippets
      .map((_, index) => {
        const url = `/${pathSnippets.slice(0, index + 1).join('/')}`
        for (let i = 0; i < routePath.length; i++) {
          const { isExact } = matchPath(url, {
            path: routePath[i],
          }) || { isExact: false }
          if (isExact) {
            return (
              <Breadcrumb.Item key={url}>
                <Link to={url}>{breadcrumbNameMap[routePath[i]]}</Link>
              </Breadcrumb.Item>
            )
          }
        }
      })
      .filter((element) => !!element) as JSX.Element[]

    return [
      <Breadcrumb.Item key='home'>
        <Link to='/'>首页</Link>
      </Breadcrumb.Item>,
    ].concat(extraBreadcrumbItems)
  }
  const breadcrumb = generateBreadcrumb()
  /**
   * @description 退出动作
   */
  const handlelogout = () => {
    sessionStorage.clear()
    window.location.href = '/login'
  }
  // 生成菜单选项
  const menus = routes
    .filter((element) => {
      return element.meunName
    })
    .map((element) => {
      return (
        <Menu.Item
          key={element.path}
          icon={<element.Icon />}
          onClick={() => {
            history.push(element.path)
          }}
        >
          {element.meunName}
        </Menu.Item>
      )
    })
  return (
    <Layout className='admin-layout'>
      <Sider theme='dark'>
        <div className='logo'>
          <h2>管理平台</h2>
        </div>
        <Menu mode='inline' theme='dark' defaultSelectedKeys={[defaultSelectedKeys]}>
          {menus}
        </Menu>
      </Sider>
      <Layout className='site-layout'>
        <Header className='site-layout-header'>
          <Dropdown
            overlay={
              <Menu>
                <Menu.Item
                  onClick={() => {
                    history.push('/personcenter')
                  }}
                >
                  个人中心
                </Menu.Item>
                <Menu.Item onClick={handlelogout}>退出</Menu.Item>
              </Menu>
            }
          >
            <a className='ant-dropdown-link' onClick={(e) => e.preventDefault()}>
              {userInfo.user} <DownOutlined />
            </a>
          </Dropdown>
        </Header>
        <Content className='admin-content'>
          <Breadcrumb className='admin-layout__breadcrumb'>{breadcrumb}</Breadcrumb>
          <div className='site-layout-background'>
            <Switch>
              {routes.map((route) => {
                if (route.redirect) {
                  return (
                    <Redirect from={route.path} key={route.path} to={route.redirect}></Redirect>
                  )
                }
                return (
                  <Route
                    {...route}
                    key={route.path}
                    component={(props) => {
                      return <route.component {...props} {...route}></route.component>
                    }}
                  ></Route>
                )
              })}
            </Switch>
          </div>
        </Content>
        <Footer style={{ textAlign: 'center' }}>chargeAdmin ©2021 Created by richard</Footer>
      </Layout>
    </Layout>
  )
}
export default adminLayout
