import React, { useState } from 'react'
import { Table, Button, Modal } from 'antd'
import { Helmet } from 'react-helmet'
import ReactDiffViewer from 'react-diff-viewer'
import { useAntdTable } from 'ahooks'
import { ColumnProps } from 'antd/lib/table'
import { pageProps } from '../../router/config'
import WithError from '../../commons/witherror'

interface LogProps {
  id: number
  username: string
  module: string
  action: string
  created_at: string
  origin: string
  target: string
}

type Iprops = pageProps<any>
const logPage: React.FC<Iprops> = ({ title }) => {
  const [modalState, changeModalState] = useState<{ visible: boolean; values?: LogProps }>({
    visible: false,
  })
  const { tableProps, error, params, pagination, run } = useAntdTable(
    (params) => ({
      url: '/v1/log/list',
      params: {
        page: params.current,
      },
    }),
    {
      defaultPageSize: 10,
    }
  )
  const colums: ColumnProps<LogProps>[] = [
    {
      title: '账户',
      dataIndex: 'username',
      key: 'username',
    },
    {
      title: '模块',
      dataIndex: 'module',
      key: 'module',
    },
    {
      title: '行为',
      dataIndex: 'action',
      key: 'action',
    },

    {
      title: '修改内容',
      render(record) {
        return (
          <Button
            type='link'
            onClick={() => {
              changeModalState({
                visible: true,
                values: {
                  ...record,
                  target: JSON.stringify(JSON.parse(record.target || '""'), null, 2),
                  origin: JSON.stringify(JSON.parse(record.origin || '""'), null, 2),
                },
              })
            }}
          >
            对比
          </Button>
        )
      },
    },
    {
      title: '操作时间',
      dataIndex: 'created_at',
      key: 'created_at',
    },
  ]
  return (
    <>
      <Helmet>
        <title>{title}</title>
      </Helmet>
      <WithError error={error} onRetry={() => run({ ...params, ...pagination })}>
        <Table
          rowKey={(record) => record.id}
          columns={colums}
          {...tableProps}
          pagination={{ ...tableProps.pagination, hideOnSinglePage: true }}
        ></Table>
      </WithError>

      <Modal
        maskClosable={false}
        onCancel={() => {
          changeModalState({ visible: false })
        }}
        width={800}
        visible={modalState.visible}
        title='日志对比'
        footer={null}
      >
        <div style={{ height: 600, overflowY: 'scroll' }}>
          <ReactDiffViewer
            disableWordDiff={true}
            oldValue={modalState.values?.origin}
            newValue={modalState.values?.target}
            splitView={true}
          />
        </div>
      </Modal>
    </>
  )
}
export default logPage
