import React from 'react'
import { Form, Input, Button, Card, message } from 'antd'
import { sha256 } from 'js-sha256'
import { UserOutlined, LockOutlined } from '@ant-design/icons'
import { useRequest } from 'ahooks'
import { Helmet } from 'react-helmet'
import { pageProps } from '../../router/config'
import './index.scss'
type loginPageProps = pageProps<any>
const loginPage: React.FC<loginPageProps> = ({ history, title }) => {
  const { loading, run } = useRequest(
    (data) => {
      return {
        url: '/v1/user/login',
        method: 'post',
        data,
      }
    },
    {
      manual: true,
      onSuccess(data) {
        sessionStorage.setItem('token', data.token)
        sessionStorage.setItem('userInfo', JSON.stringify(data))
        message.success('登录成功', 1, () => {
          history.push('/')
        })
      },
      onError: (error) => {
        message.error(error.message)
      },
    }
  )
  const onFinish = (values: any) => {
    run({
      ...values,
      password: sha256(values.password),
    }).catch((error) => {})
  }
  return (
    <>
      <Helmet>
        <title>{title}</title>
      </Helmet>
      <Card title='机构管理平台' className='login-card' bordered>
        <Form
          name='normal_login'
          className='login-form'
          initialValues={{ remember: true }}
          onFinish={onFinish}
        >
          <Form.Item
            label='账号'
            name='user'
            rules={[{ required: true, message: '请输入您的账号!' }]}
          >
            <Input prefix={<UserOutlined />} placeholder='账号' />
          </Form.Item>
          <Form.Item
            label='密码'
            name='password'
            rules={[{ required: true, message: '请输入密码!' }]}
          >
            <Input prefix={<LockOutlined />} type='password' placeholder='密码' />
          </Form.Item>
          <Form.Item>
            <Button type='primary' htmlType='submit' block loading={loading}>
              登录
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </>
  )
}
export default loginPage
