import React from 'react'
import { Form, Input, Button, message } from 'antd'
import { Helmet } from 'react-helmet'
import { useRequest } from 'ahooks'
import { sha256 } from 'js-sha256'
import { pageProps } from '../../router/config'

type Iprops = pageProps<any>

/**
 * @description 个人中心页面
 * @returns
 */
const personCenter: React.FC<Iprops> = ({ title }) => {
  const [form] = Form.useForm()
  const { run, loading } = useRequest(
    (data) => {
      return {
        method: 'PUT',
        data: {
          ...data,
          old: sha256(data.old),
          new: sha256(data.new),
        },
        url: '/v1/user/password',
      }
    },
    {
      manual: true,
      onSuccess() {
        message.success('密码修改成功!')
        form.resetFields()
      },
      onError(error) {
        message.error(error.message)
      },
    }
  )
  return (
    <>
      <Helmet>
        <title>{title}</title>
      </Helmet>
      <Form labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} onFinish={run}>
        <Form.Item
          label='旧密码'
          name='old'
          required
          rules={[{ required: true, message: '请输入旧密码' }]}
        >
          <Input.Password placeholder='请输入旧密码'></Input.Password>
        </Form.Item>
        <Form.Item
          label='新密码'
          name='new'
          required
          rules={[{ required: true, message: '请输入新密码' }]}
        >
          <Input.Password placeholder='请输入新密码'></Input.Password>
        </Form.Item>
        <Form.Item
          label='重复密码'
          name='confirm_password'
          required
          dependencies={['new']}
          rules={[
            { required: true, message: '重复输入新密码' },
            ({ getFieldValue }) => ({
              validator(_, value) {
                if (!value || getFieldValue('new') === value) {
                  return Promise.resolve()
                }
                return Promise.reject(new Error('密码不一致!'))
              },
            }),
          ]}
        >
          <Input.Password placeholder='重复输入新密码'></Input.Password>
        </Form.Item>
        <Form.Item wrapperCol={{ offset: 6, span: 6 }}>
          <Button block type='primary' htmlType='submit' loading={loading}>
            提交
          </Button>
        </Form.Item>
      </Form>
    </>
  )
}
export default personCenter
